@@ -1,8 +1,14 @@
+# frozen_string_literal: true
 module YARD
   module Parser::Ruby::Legacy
     class Statement
       attr_reader :tokens, :comments, :block
-      attr_accessor :comments_range, :group
+      attr_accessor :comments_range
+
+      # @deprecated Groups are now defined by directives
+      # @see Tags::GroupDirective
+      attr_accessor :group
+
       attr_accessor :comments_hash_flag
 
       def initialize(tokens, block = nil, comments = nil)
@@ -31,7 +37,7 @@ module YARD
       end
 
       def show
-        "\t #{line}: #{first_line}"
+        "\t#{line}: #{first_line}"
       end
 
       # @return [Fixnum] the first line of Ruby source
@@ -51,10 +57,10 @@ module YARD
         last_tk = nil
         tokens.reject do |tk|
           tk.is_a?(RubyToken::TkNL) ||
-          (last_tk.is_a?(RubyToken::TkSPACE) &&
-          last_tk.class == tk.class) && last_tk = tk
+            (last_tk.is_a?(RubyToken::TkSPACE) &&
+            last_tk.class == tk.class) && last_tk = tk
         end
       end
     end
   end
-end
\ No newline at end of file
+end
