@@ -1,8 +1,9 @@
+# frozen_string_literal: true
 def init
   sections :search, [T('../default/layout')]
 end
 
 def search
-  options[:breadcrumb_title] = h("Search for '#{@query}'")
+  options.breadcrumb_title = h("Search for '#{@query}'")
   yieldall :contents => erb(:search)
-end
\ No newline at end of file
+end
