@@ -1,6 +1,7 @@
+# frozen_string_literal: true
 require File.dirname(__FILE__) + "/spec_helper"
 
-describe YARD::Handlers::C::MixinHandler do
+RSpec.describe YARD::Handlers::C::MixinHandler do
   it "adds includes to modules or classes" do
     parse_init <<-eof
       mFoo = rb_define_module("Foo");
