@@ -296,6 +296,11 @@ eof
           expect(node.source).to eq(str[/(\%#{id}\(.+\))/m, 1])
         end
       end
+
+      it "tokenizing %#{id}(...) returns correct tokens" do
+        toks = tokenize("TEST = %#{id}(A B C)").flatten
+        expect(toks.count(:tstring_content)).to eq(3)
+      end
     end
 
     it "parses %w() array in constant declaration" do
@@ -400,6 +405,19 @@ eof
       expect(Registry.at("Foo::CONST2").docstring).to eq "Another comment here"
     end
 
+    it "handles comments in the middle of a multi-line statement" do
+      Registry.clear
+      YARD.parse_string <<-eof
+        foo # BREAK
+        .bar
+
+        # Documentation
+        class Baz; end
+      eof
+      expect(Registry.at('Baz')).not_to be_nil
+      expect(Registry.at('Baz').docstring).to eq 'Documentation'
+    end
+
     %w(if unless).each do |type|
       it "does not get confused by modifier '#{type}' statements" do
         Registry.clear
