@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 include T('default/layout/html')
 include YARD::Parser::Ruby::Legacy
 
@@ -14,9 +15,27 @@ def all_objects
   @objects.map {|obj| obj.format(options) }.join("\n")
 end
 
+def layout
+  layout = Object.new.extend(T('layout'))
+  @css_data = layout.stylesheets.map {|sheet| read_asset(sheet) }.join("\n")
+  @js_data = layout.javascripts.map {|script| read_asset(script) }.join("")
+
+  erb(:layout)
+end
+
+def read_asset(file)
+  file = T('fulldoc').find_file(file)
+  return unless file
+  data = File.read(file)
+  superfile = self.class.find_nth_file('fulldoc', 2)
+  data.gsub!('{{{__super__}}}', superfile ? IO.read(superfile) : "")
+  data
+end
+
 private
 
 def parse_top_comments_from_file
+  return unless defined?(@readme) && @readme
   return @readme.contents unless @readme.filename =~ /\.rb$/
   data = ""
   tokens = TokenList.new(@readme.contents)
@@ -30,14 +49,14 @@ end
 def override_serializer
   return if @serializer.nil?
   class << @serializer
-    def serialize(object, data)
+    define_method(:serialize) do |object, data|
       return unless object == 'index.html'
-      super
+      super(object, data)
     end
 
-    def serialized_path(object)
+    define_method(:serialized_path) do |object|
       return object if object.is_a?(String)
-      return 'index.html'
+      'index.html'
     end
   end
-end
\ No newline at end of file
+end
